@@ -11,3 +11,15 @@ impl ISolana for Solana {
         String::from("192.168.1.1")
     }
 }
+
+impl Solana {
+    pub fn new() -> Self {
+        Solana{}
+    }
+}
+
+pub fn resolve() -> impl ISolana {
+    Solana::new()
+}
+
+
